DeriveJunction class

A since derivation junction description. It is the single parameter used when creating a new secret key from an existing secret key and, in the case of SoftRaw and SoftIndex a new public key from an existing public key.

Constructors

DeriveJunction(bool hardenedDerivation, List<int> junctionId)
const
DeriveJunction.fromBytes(bool hard, Uint8List junctionId)
Create a new DeriveJunction from a given byte encoded value.
factory
DeriveJunction.fromStr(String str)
factory

Properties

hardenedDerivation → bool
false -> Soft (vanilla) derivation. Public keys have a correspondent derivation. true -> Hard ("hardened") derivation. Public keys do not have a correspondent derivation.
final
hashCode → int
The hash code for this object.
no setteroverride
isHard → bool
Return true if the junction is hard.
no setter
isSoft → bool
Return true if the junction is soft.
no setter
junctionId → List<int>
inner junction id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

junctionIdLength → const int
The length of the junction identifier. Note that this is also referred to as the CHAIN_CODE_LENGTH in the context of Schnorrkel.